@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provides musical cadence chords
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Music::Chord::Note;
 use Music::Scales;
@@ -22,7 +22,7 @@ sub cadence {
     $args{key}       ||= 'C';
     $args{scale}     ||= 'major';
     $args{type}      ||= 'perfect';
-    $args{variation} //= 0;
+    $args{variation} ||= 1;
     $args{octave}    //= 0;
 
     my $n     = 0;
@@ -87,7 +87,7 @@ Music::Cadence - Provides musical cadence chords
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
